@@ -1,8 +1,11 @@
 // @ts-check
 
+import babel from "@rollup/plugin-babel";
 import commonjs from "@rollup/plugin-commonjs";
 import esmShim from "@rollup/plugin-esm-shim";
 import json from "@rollup/plugin-json";
+import nodeResolve from "@rollup/plugin-node-resolve";
+import replace from "@rollup/plugin-replace";
 import typescript from "@rollup/plugin-typescript";
 import { defineConfig } from "rollup";
 import copy from "rollup-plugin-copy";
@@ -10,7 +13,7 @@ import { minify } from "rollup-plugin-esbuild";
 
 const prodEnv = process.env.BUILD === "prod";
 
-const electronExternals = ["electron", "node:fs", "node:path", "node:os", "node:url"];
+const electronExternals = ["electron", "node:fs", "node:path", "node:os", "node:url", "@vencord/venmic"];
 
 export default defineConfig([
     {
@@ -23,10 +26,11 @@ export default defineConfig([
         external: [
             ...electronExternals,
             "electron",
-            "v8-compile-cache",
             "electron-is-dev",
+            "electron-updater",
             "electron-context-menu",
             "arrpc",
+            "path",
             "stream",
             "stream/promises",
         ],
@@ -51,8 +55,8 @@ export default defineConfig([
         input: "src/discord/preload/preload.mts",
         output: {
             dir: "ts-out/discord",
-            entryFileNames: "[name].cjs",
-            format: "cjs",
+            entryFileNames: "[name].mjs",
+            format: "esm",
             sourcemap: true,
         },
         external: electronExternals,
@@ -81,9 +85,9 @@ export default defineConfig([
         plugins: [typescript(), minify({ minify: prodEnv })],
     },
     {
-        input: "src/themeManager/preload.mts",
+        input: "src/cssEditor/preload.mts",
         output: {
-            dir: "ts-out/themeManager",
+            dir: "ts-out/cssEditor",
             format: "esm",
             entryFileNames: "[name].mjs",
             sourcemap: true,
@@ -92,14 +96,28 @@ export default defineConfig([
         plugins: [typescript(), minify({ minify: prodEnv })],
     },
     {
-        input: "src/screenshare/preload.mts",
+        input: "src/setup/setup.tsx",
         output: {
-            dir: "ts-out/screenshare",
+            dir: "ts-out/html",
             format: "esm",
-            entryFileNames: "[name].mjs",
+            entryFileNames: "[name].js",
             sourcemap: true,
         },
         external: electronExternals,
-        plugins: [typescript(), minify({ minify: prodEnv })],
+        plugins: [
+            commonjs(),
+            replace({
+                "process.env.NODE_ENV": JSON.stringify("production"),
+            }),
+            nodeResolve({ browser: true }),
+            typescript(),
+            minify({ minify: prodEnv }),
+            babel({
+                presets: ["solid"],
+                babelHelpers: "bundled",
+                exclude: "node_modules/**",
+                extensions: [".ts", ".tsx"],
+            }),
+        ],
     },
 ]);
