@@ -10,7 +10,17 @@ const defaults: Settings = {
     legcordCSP: true,
     minimizeToTray: true,
     keybinds: [],
-    audio: "loopbackWithMute",
+    audio: {
+        workaround: false,
+        deviceSelect: true,
+        granularSelect: true,
+        ignoreVirtual: false,
+        ignoreDevices: false,
+        ignoreInputMedia: false,
+        onlySpeakers: false,
+        onlyDefaultSpeakers: true,
+        loopbackType: "loopback",
+    },
     multiInstance: false,
     mods: ["vencord"],
     transparency: "none",
@@ -24,13 +34,21 @@ const defaults: Settings = {
     customJsBundle: "https://legcord.app/placeholder.js",
     customCssBundle: "https://legcord.app/placeholder.css",
     disableAutogain: false,
-    useLegacyCapturer: false,
+    autoHideMenuBar: true,
+    blockPowerSavingInVoiceChat: false,
+    useMacSystemPicker: true,
     mobileMode: false,
     tray: "dynamic",
     doneSetup: false,
+    popoutPiP: false,
+    spellcheckLanguage: ["en-US"],
+    sleepInBackground: false,
+    noBundleUpdates: false,
+    additionalArguments: "",
     customIcon: join(import.meta.dirname, "../", "/assets/desktop.png"),
     smoothScroll: true,
     autoScroll: false,
+    useSystemCssEditor: false,
 };
 export function checkForDataFolder(): void {
     const dataPath = join(dirname(app.getPath("exe")), "legcord-data");
@@ -82,27 +100,57 @@ export function checkIfConfigExists(): void {
         console.log("Created missing user data folder");
     }
 
-    if (!existsSync(settingsFile)) {
-        if (!existsSync(storagePath)) {
-            mkdirSync(storagePath);
-            console.log("Created missing storage folder");
+    try {
+        if (!existsSync(settingsFile)) {
+            if (!existsSync(storagePath)) {
+                mkdirSync(storagePath);
+                console.log("Created missing storage folder");
+            }
+            console.log("First run of the Legcord. Starting setup.");
+            setup();
+            firstRun = true;
+        } else if (!getConfig("doneSetup")) {
+            console.log("First run of the Legcord. Starting setup.");
+            setup();
+            firstRun = true;
+        } else {
+            console.log("Legcord has been run before. Skipping setup.");
         }
-        console.log("First run of the Legcord. Starting setup.");
-        setup();
-        firstRun = true;
-    } else if (getConfig("doneSetup") === false) {
-        console.log("First run of the Legcord. Starting setup.");
-        setup();
-        firstRun = true;
-    } else {
-        console.log("Legcord has been run before. Skipping setup.");
+    } catch {
+        checkIfConfigIsBroken();
     }
 }
 export function checkIfConfigIsBroken(): void {
     try {
         const settingsData = readFileSync(getConfigLocation(), "utf-8");
-        JSON.parse(settingsData);
-        console.log("Config is fine");
+        const settingsObject = JSON.parse(settingsData) as Settings;
+
+        let configWasFine = true;
+        const settingsKeys = Object.keys(settingsObject) as (keyof Settings)[];
+        const defaultKeys = Object.keys(defaults) as (keyof Settings)[];
+
+        const missingKeysInSettings = defaultKeys.filter((key) => !settingsKeys.includes(key));
+        configWasFine = missingKeysInSettings.length === 0;
+
+        defaultKeys.forEach((key: keyof Settings) => {
+            const valueInSettings = settingsObject[key];
+            const valueInDefaults = defaults[key];
+            if (!valueInSettings || !valueInDefaults) return;
+            if (typeof valueInDefaults !== typeof valueInSettings) {
+                console.log(
+                    `Root config ${key} type (${typeof valueInSettings}) differs from default type (${typeof valueInDefaults}). Setting default value...`,
+                );
+                setConfig(key, valueInDefaults);
+                configWasFine = false;
+            }
+        });
+
+        missingKeysInSettings.forEach((missingKey) => {
+            console.log(`Missing config root entry ${missingKey}, setting default config for this entry...`);
+            setConfig(missingKey, defaults[missingKey]);
+        });
+
+        console.log(configWasFine ? "Config is fine" : "Config is now fine");
     } catch (e) {
         console.error(e);
         console.log("Detected a corrupted config");
