@@ -24,7 +24,10 @@ import { init } from "../main.js";
 import { registerGlobalKeybinds } from "./globalKeybinds.js";
 import { registerIpc } from "./ipc.js";
 import { setMenu } from "./menu.js";
+import { registerCustomHandler } from "./screenshare.js";
+import { mainTouchBar } from "./touchbar.js";
 import { createTray, tray } from "./tray.js";
+import { registerVenmicIpc } from "./venmic.js";
 export let mainWindows: BrowserWindow[] = [];
 export let inviteWindow: BrowserWindow;
 
@@ -64,6 +67,7 @@ function doAfterDefiningTheWindow(passedWindow: BrowserWindow): void {
 
     const ignoreProtocolWarning = getConfig("ignoreProtocolWarning");
     registerIpc(passedWindow);
+    registerVenmicIpc();
     if (getConfig("mobileMode")) {
         passedWindow.webContents.userAgent =
             "Mozilla/5.0 (Linux; Android 6.0; Nexus 5 Build/MRA58N) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/102.0.5005.149 Mobile Safari/537.36";
@@ -93,7 +97,7 @@ function doAfterDefiningTheWindow(passedWindow: BrowserWindow): void {
             })();
         });
     }
-    app.on("activate", () => {
+    app.on("activate", async () => {
         app.show();
     });
     passedWindow.webContents.on("frame-created", (_, { frame }) => {
@@ -114,7 +118,10 @@ function doAfterDefiningTheWindow(passedWindow: BrowserWindow): void {
         if (url === "about:blank") return { action: "allow" };
         // Saving ics files on future events
         if (url.startsWith("blob:https://discord.com/")) {
-            return { action: "allow", overrideBrowserWindowOptions: { show: false } };
+            return {
+                action: "allow",
+                overrideBrowserWindowOptions: { show: false },
+            };
         }
         // Allow Discord stream popout
         if (
@@ -125,7 +132,7 @@ function doAfterDefiningTheWindow(passedWindow: BrowserWindow): void {
             return {
                 action: "allow",
                 overrideBrowserWindowOptions: {
-                    alwaysOnTop: true,
+                    alwaysOnTop: getConfig("popoutPiP"),
                 },
             };
         if (url.startsWith("https:") || url.startsWith("http:") || url.startsWith("mailto:")) {
@@ -161,13 +168,15 @@ function doAfterDefiningTheWindow(passedWindow: BrowserWindow): void {
 
         return { action: "deny" };
     });
-    if (getConfig("useLegacyCapturer") === false) {
-        console.log("Starting screenshare module...");
-        void import("../screenshare/main.js"); // REVIEW - This is probably bad.
-    }
+
+    passedWindow.webContents.session.setSpellCheckerLanguages(getConfig("spellcheckLanguage"));
+
+    registerCustomHandler();
 
     passedWindow.webContents.session.webRequest.onBeforeRequest(
-        { urls: ["https://*/api/v*/science", "https://sentry.io/*", "https://*.nel.cloudflare.com/*"] },
+        {
+            urls: ["https://*/api/v*/science", "https://sentry.io/*", "https://*.nel.cloudflare.com/*"],
+        },
         (_, callback) => callback({ cancel: true }),
     );
     // fix UMG video playback
@@ -198,8 +207,8 @@ function doAfterDefiningTheWindow(passedWindow: BrowserWindow): void {
             }
         });
     }
-
     initQuickCss(passedWindow);
+    passedWindow.setTouchBar(mainTouchBar);
     passedWindow.webContents.on("page-title-updated", (e, title) => {
         const legcordSuffix = " - Legcord"; /* identify */
 
@@ -292,6 +301,7 @@ function doAfterDefiningTheWindow(passedWindow: BrowserWindow): void {
     if (firstRun) {
         passedWindow.close();
     }
+
     registerGlobalKeybinds();
     switch (getConfig("channel")) {
         case "stable":
@@ -325,10 +335,13 @@ export function createWindow() {
         icon: getConfig("customIcon") ?? path.join(import.meta.dirname, "../", "/assets/desktop.png"),
         frame: false,
         backgroundColor: "#202225",
-        autoHideMenuBar: true,
+        autoHideMenuBar: getConfig("autoHideMenuBar"),
         webPreferences: {
-            sandbox: false,
-            preload: path.join(import.meta.dirname, "discord/preload.cjs"),
+            sandbox: true,
+            nodeIntegration: false,
+            contextIsolation: true,
+            backgroundThrottling: getConfig("sleepInBackground"),
+            preload: path.join(import.meta.dirname, "discord/preload.mjs"),
             spellcheck: getConfig("spellcheck"),
         },
     };
@@ -376,7 +389,7 @@ export function createInviteWindow(code: string): void {
         darkTheme: true,
         icon: getConfig("customIcon") ?? path.join(import.meta.dirname, "../", "/assets/desktop.png"),
         frame: true,
-        autoHideMenuBar: true,
+        autoHideMenuBar: getConfig("autoHideMenuBar"),
         webPreferences: {
             sandbox: false,
             spellcheck: getConfig("spellcheck"),
